@@ -6,6 +6,18 @@ fn agudo() {
     assert_eq!(word.rhyme(), "é");
 }
 
+#[test]
+fn corta() {
+    let word: Word = "y".into();
+    assert_eq!(word.rhyme(), "y");
+}
+
+#[test]
+fn invalida() {
+    let word: Word = "nn".into();
+    assert_eq!(word.rhyme(), "");
+}
+
 #[test]
 fn agudo2() {
     let word: Word = "huir".into();
