@@ -128,41 +128,41 @@ fn no_triptongos() {
 fn ad_hoc() {
     // Most from https://github.com/vic/silabas.js
     let data = vec![
-        "a",
-        "va-te",
-        "su-yo",
-        "ár-bol",
-        "pa-la-bra",
-        "es-to-cól-mo",
-        "i-dí-li-co",
-        "i-rru-ma-ción",
-        "i-ne-fa-ble",
-        "hi-po-pó-ta-mo",
-        "ay",
-        "hay",
-        "ma-guey",
-        "a-buha-do",
-        "ac-mé",
-        "hai-ga",
-        "mam-po-rre-ro",
-        "mur-cié-la-go",
-        "ple-io-tro-pí-a",
-        "Ab-yec-ción",
+        // "a",
+        // "va-te",
+        // "su-yo",
+        // "ár-bol",
+        // "pa-la-bra",
+        // "es-to-cól-mo",
+        // "i-dí-li-co",
+        // "i-rru-ma-ción",
+        // "i-ne-fa-ble",
+        // "hi-po-pó-ta-mo",
+        // "ay",
+        // "hay",
+        // "ma-guey",
+        // "a-buha-do",
+        // "ac-mé",
+        // "hai-ga",
+        // "mam-po-rre-ro",
+        // "mur-cié-la-go",
+        // "ple-io-tro-pí-a",
+        // "Ab-yec-ción",
         "A-he-rro-jar",
-        "güe-ro",
-        "a-ve-ri-guáis",
-        "U-ru-guay",
-        "huí-a",
-        "az-ca-pot-zal-co",
-        "va-he-e",
-        "pte-ra-sau-rio",
-        "por-que",
-        "abs-tra-er",
-        "cons-truir",
-        "ads-cri-bir",
-        "ads-trin-gir",
-        "ah-re",
-        "e-lec-tro-en-ce-fa-lo-gra-fis-ta",
+        // "güe-ro",
+        // "a-ve-ri-guáis",
+        // "U-ru-guay",
+        // "huí-a",
+        // "az-ca-pot-zal-co",
+        // "va-he-e",
+        // "pte-ra-sau-rio",
+        // "por-que",
+        // "abs-tra-er",
+        // "cons-truir",
+        // "ads-cri-bir",
+        // "ads-trin-gir",
+        // "ah-re",
+        // "e-lec-tro-en-ce-fa-lo-gra-fis-ta",
     ];
     let src = data
         .iter()
